@@ -86,7 +86,7 @@ session_info["thread_safe"] = False
 session_info["lazy"] = True
 session_info["precision"] = None
 session_info["parallel"] = False
-session_info["progress"] = "auto"
+session_info["progress"] = "on"
 session_info["checks"] = True
 
 session_info["interactive"] = sys.__stdin__.isatty()
@@ -111,6 +111,7 @@ def update_options(kwargs):
     valid_keys = ["thread_safe", "lazy", "cores", "precision", "temp_dir", "parallel", "checks", "progress"]
 
     for key in kwargs:
+        find = True
         if key not in valid_keys:
             raise AttributeError(key + " is not a valid option")
 
@@ -122,15 +123,15 @@ def update_options(kwargs):
             if type(kwargs[key]) is not bool:
                 raise TypeError(f"{key} should be boolean")
 
-        if type(kwargs[key]) is not bool:
+        if type(kwargs[key]) is not bool and find:
             if key == "temp_dir":
                 if type(kwargs[key]) is str:
                     if os.path.exists(kwargs[key]) is False:
                         raise ValueError("The temp_dir specified does not exist!")
                     session_info[key] = os.path.abspath(kwargs[key])
                     session_info["user_dir"] = True
-                return None
-            if key == "progress":
+                find = False
+            if key == "progress" and find:
                 if kwargs[key] not in ["on", "off", "auto", "of"]:
                     raise ValueError("progress must be one of 'on', 'off', 'auto'")
 
@@ -138,9 +139,9 @@ def update_options(kwargs):
                     session_info[key] = "off" 
                 else:
                     session_info[key] = kwargs[key]
-                return None
+                find = False
 
-            if key == "cores":
+            if key == "cores" and find:
                 if type(kwargs[key]) is int:
                     if kwargs[key] > mp.cpu_count():
                         raise ValueError(
@@ -150,23 +151,26 @@ def update_options(kwargs):
                             + ")"
                         )
                     session_info[key] = kwargs[key]
+                    find = False
                 else:
                     raise TypeError("cores must be an int")
             else:
-                if key == "precision":
-                    if kwargs[key] not in ["I8", "I16", "I32", "F32", "F64", "default"]:
-                        raise ValueError("precision supplied is not valid!")
-                    if kwargs[key] == "default":
-                        session_info[key] = None 
+                if find:
+                    if key == "precision":
+                        if kwargs[key] not in ["I8", "I16", "I32", "F32", "F64", "default"]:
+                            raise ValueError("precision supplied is not valid!")
+                        if kwargs[key] == "default":
+                            session_info[key] = None 
+                        else:
+                            session_info[key] = kwargs[key]
+                        find = False
                     else:
-                        session_info[key] = kwargs[key]
-                else:
-                    raise ValueError(kwargs[key] + " is not valid session info!")
+                        raise ValueError(kwargs[key] + " is not valid session info!")
         else:
             session_info[key] = kwargs[key]
 
             # update safe-lists etc. if running in parallel
-            if kwargs[key] and key == "parallel":
+            if kwargs[key] and key == "parallel" and find:
 
                 if len(temp_dirs) > 0:
                     for ff in temp_dirs:
@@ -181,7 +185,7 @@ def update_options(kwargs):
                         nc_protected_par.append(ff)
                         nc_protected.remove(ff)
 
-            if (kwargs[key] is False) and key == "parallel":
+            if (kwargs[key] is False) and key == "parallel" and find:
 
                 if len(temp_dirs_par) > 0:
                     for ff in temp_dirs_par:
@@ -1569,6 +1573,11 @@ class DataSet(object):
     from nctoolkit.add_etc import sqrt
     from nctoolkit.add_etc import day_stat
     from nctoolkit.add_etc import rmse
+    from nctoolkit.add_etc import __add__
+    from nctoolkit.add_etc import __truediv__
+    from nctoolkit.add_etc import __sub__
+    from nctoolkit.add_etc import __mul__
+    from nctoolkit.add_etc import __pow__
 
     from nctoolkit.anomaly import annual_anomaly
     from nctoolkit.anomaly import monthly_anomaly
@@ -1591,9 +1600,19 @@ class DataSet(object):
     from nctoolkit.clear import reset
 
     from nctoolkit.compare import compare
+    from nctoolkit.compare import __eq__
+    from nctoolkit.compare import __gt__
+    from nctoolkit.compare import __lt__
+    from nctoolkit.compare import __le__
+    from nctoolkit.compare import __ge__
+    from nctoolkit.compare import __ne__
 
     from nctoolkit.compare_data import gt
     from nctoolkit.compare_data import lt
+    from nctoolkit.compare_data import le
+    from nctoolkit.compare_data import ge
+    from nctoolkit.compare_data import ne
+    from nctoolkit.compare_data import eq
 
     from nctoolkit.corr import cor_space
     from nctoolkit.corr import cor_time
