@@ -3,6 +3,7 @@ from nctoolkit.temp_file import temp_file
 from nctoolkit.api import open_data
 from netCDF4 import Dataset
 import subprocess
+import warnings
 
 def is_corrupt(self):
     """
@@ -99,51 +100,59 @@ def check(self):
 
     if cf_checker:
         for ff in self:
-            ds = xr.open_dataset(ff, decode_times=False)
-            if "Conventions" not in list(ds.attrs.keys()):
-                print(f"No CF-conventions in {ff}")
-            else:
-                version = ds.attrs["Conventions"].split("-")[1]
+            version = ""
+            try:
+                ds = xr.open_dataset(ff, decode_times=False)
+                if "Conventions" not in list(ds.attrs.keys()):
+                    print(f"No CF-conventions in {ff}")
+                else:
+                    version = ds.attrs["Conventions"].split("-")[1]
+            except:
+                warnings.warn("Note: there are issues opening this file using xarray. You may want to look closely to see if there are formatting issues that will have negative downstream impacts!")
 
+            if len(version) > 0:
                 command = f"cfchecks -v {version} {ff}"
-                out = subprocess.Popen(
-                    command,
-                    shell=True,
-                    stdin=subprocess.PIPE,
-                    stdout=subprocess.PIPE,
-                    stderr=subprocess.STDOUT,
-                )
-                result, ignore = out.communicate()
+            else:
+                command = f"cfchecks {ff}"
 
-                result_split = result.decode("utf-8").split("\n")
-                splits = [
-                    index
-                    for index, value in enumerate(result_split)
-                    if "Checking variable" in value
-                ]
-                end = [
-                    index
-                    for index, value in enumerate(result_split)
-                    if "ERRORS dete" in value
-                ][0]
-                for i in range(0, len(splits)):
-                    if i < (len(splits) - 1):
+            out = subprocess.Popen(
+                command,
+                shell=True,
+                stdin=subprocess.PIPE,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.STDOUT,
+            )
+            result, ignore = out.communicate()
 
-                        i_result = result_split[splits[i] : splits[i + 1]]
-                        i_result = "\n".join(i_result)
-                        if "ERROR: " in i_result:
-                            i_result = i_result.replace(
-                                "Checking variable:", "Issue with variable:"
-                            )
-                            print(i_result)
-                    else:
-                        i_result = result_split[splits[i] : end]
-                        i_result = "\n".join(i_result)
-                        if "ERROR: " in i_result:
-                            i_result = i_result.replace(
-                                "Checking variable:", "Issue with variable:"
-                            )
-                            print(i_result)
+            result_split = result.decode("utf-8").split("\n")
+            splits = [
+                index
+                for index, value in enumerate(result_split)
+                if "Checking variable" in value
+            ]
+            end = [
+                index
+                for index, value in enumerate(result_split)
+                if "ERRORS dete" in value
+            ][0]
+            for i in range(0, len(splits)):
+                if i < (len(splits) - 1):
+
+                    i_result = result_split[splits[i] : splits[i + 1]]
+                    i_result = "\n".join(i_result)
+                    if "ERROR: " in i_result:
+                        i_result = i_result.replace(
+                            "Checking variable:", "Issue with variable:"
+                        )
+                        print(i_result)
+                else:
+                    i_result = result_split[splits[i] : end]
+                    i_result = "\n".join(i_result)
+                    if "ERROR: " in i_result:
+                        i_result = i_result.replace(
+                            "Checking variable:", "Issue with variable:"
+                        )
+                        print(i_result)
 
     print("*****************************************")
     print("Checking grid consistency")
