@@ -68,6 +68,7 @@ def split_cdo(self, method="year"):
 
     self._merged = False
     self.current = new_files
+    self.current.sort()
 
     # remove the bases from the split list. This is for parallel processing
 
@@ -87,10 +88,10 @@ def split(self, by=None):
     Parameters
     --------------------
     by : str
-        Available by arguments are 'year', 'month', 'yearmonth', 'season', 'day' 'name'.
+        Available by arguments are 'year', 'month', 'yearmonth', 'season', 'day' 'name', "timestep".
         year will split files by year, month will split files by month, yearmonth
         will split files by year and month; season will split files by year, day
-        will split files by day.
+        will split files by day. Using "timestep" will split files by timestep.
         'name' will split by variable name
 
     Examples
@@ -113,6 +114,9 @@ def split(self, by=None):
     if by == "year":
         method = "year"
 
+    if by == "timestep":
+        method = "sel,1"
+
     if by == "month":
         method = "mon"
 
